import re

class SyllableSeparator:
    def __init__(self):
        #「((ウ段＋「ァ/ィ/ェ/ォ」)|(イ段（「イ」を除く）＋「ャ/ュ/ェ/ョ」)|( 「テ/デ」＋「ィ/ュ」)|(大文字カナ))(「ー/ッ/ン」の連続文字列（０文字含む）)」の正規表現
        c1 = '[ウクスツヌフムユルグズヅブプヴ][ヮァィェォ]' #ウ段＋「ァ/ィ/ェ/ォ」
        c2 = '[イキシシニヒミリギジヂビピ][ャュェョ]' #イ段（「イ」を除く）＋「ャ/ュ/ェ/ョ」
        c3 = '[テデ][ィュ]' #「テ/デ」＋「ィ/ュ」
        c4 = '[アイウエオカ-ヂツ-モヤユヨ-ヲヴ]' #大文字カナ
        c5 = '[ーッン]*' #「ー/ッ/ン」の連続文字列（０文字含む）

        cond = '(?:'+c1+'|'+c2+'|'+c3+'|'+c4+')'+c5 #(?:)はサブパターンの参照を避けるカッコ
        cond = '('+cond+')'
        self.re_syllable = re.compile(cond)

    def parse(self, kana_text):
        return self.re_syllable.findall(kana_text)



import unittest
from jasyllablesep import parse

class TestSyllableSeparator(unittest.TestCase):
    def test_parse(self):
        cases = [
            ("シンシュンシャンソンショー", ['シン', 'シュン', 'シャン', 'ソン', 'ショー']),
            ("トーキョートッキョキョカキョク", ['トー', 'キョー', 'トッ', 'キョ', 'キョ', 'カ', 'キョ', 'ク']),
            ("アウトバーン", ['ア', 'ウ', 'ト', 'バーン']),
            ("ガッキュウホウカイ", ['ガッ', 'キュ', 'ウ', 'ホ', 'ウ', 'カ', 'イ'])
        ]
        
        for text, expected in cases:
            with self.subTest(text=text):
                self.assertEqual(parse(text), expected)

if __name__ == '__main__':
    unittest.main()



from setuptools import setup, find_packages

setup(
    name='jasyllablesep',
    version='0.0.0',
    packages=find_packages(),
    author='shimajiroxyza',
    author_email='shimaya.jiro@irl.sys.es.osaka-u.ac.jp',
    description='A package for separating Japanese text into syllables',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/jiroshimaya/jasyllablesep',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)
